# VAI toolkit

## Quickstart

To add data to our platform, use the package below.

pip install vai-toolkit

for more information, checkout our other page [documentation](https://virtuousai.bitbucket.io/docs/vai-toolkit/)